Struct tor_units::BoundedInt32

source ·
pub struct BoundedInt32<const LOWER: i32, const UPPER: i32> { /* private fields */ }
A 32-bit signed integer with a restricted range.

This type holds an i32 value such that LOWER <= value <= UPPER

Limitations

If you try to instantiate this type with LOWER > UPPER, you will get an uninhabitable type. It would be better if we could check that at compile time, and prevent such types from being named.

Implementations

Lower bound

Upper bound

Return the underlying i32 value.

This value will always be between Self::LOWER and Self::UPPER, inclusive.

If val is within range, return a new BoundedInt32 wrapping it; otherwise, clamp it to the upper or lower bound as appropriate.

If val is an acceptable value inside the range for this type, return a new BoundedInt32. Otherwise return an error.

Convert from the underlying type, clamping to the upper or lower bound if needed.

Panics

This function will panic if UPPER < LOWER.

Convert from a string, clamping to the upper or lower bound if needed.

Limitations

If the input is a number that cannot be represented as an i32, then we return an error instead of clamping it.